{% extends "layouts/base.html" %} {% block title %}UI Ribbons {% endblock %} {% block body_class %}{% endblock body_class %} {% block stylesheets %} {% endblock stylesheets %} {% block content %}

# Ribbons

Ribbon
Ribbon Default
.ribbon-wrapper.ribbon-lg .ribbon
Ribbon Large
Ribbon Large
.ribbon-wrapper.ribbon-lg .ribbon
Ribbon Extra Large
Ribbon Extra Large
.ribbon-wrapper.ribbon-xl .ribbon
Ribbon
Ribbon Large
with Large Text
.ribbon-wrapper.ribbon-lg .ribbon.text-lg
Ribbon
Ribbon Extra Large
with Large Text
.ribbon-wrapper.ribbon-xl .ribbon.text-lg
Ribbon
Ribbon Extra Large
with Extra Large Text
.ribbon-wrapper.ribbon-xl .ribbon.text-xl
Ribbon
Ribbon
Ribbon
{% endblock content %} {% block javascripts %}
{% endblock javascripts %}